@@ -19,8 +19,6 @@
 */
 
 #include <glib.h>
-#include <glib/ghash.h>
-#include <glib/glist.h>
 #include <string.h>
 
 #include "mw_channel.h"
@@ -906,6 +904,9 @@ void mwChannel_addSupportedCipherInstance(struct mwChannel *chan,
 
 
 static void collect(gpointer a, gpointer b, gpointer c) {
+  // `a` isn't used
+  (void)a;
+
   GList **list = c;
   *list = g_list_append(*list, b);
 }
