@@ -688,6 +688,17 @@ void mwUserStatus_get(struct mwGetBuffer *b, struct mwUserStatus *stat) {
   guint16_get(b, &stat->status);
   guint32_get(b, &stat->time);
   mwString_get(b, &stat->desc);
+
+  // # User Mikael Berthe <mikael.berthe@lilotux.net>
+  // # Date 1195749751 -3600
+  // Fix Awareness status timestamps with recent Sametime clients
+
+  // For some reason the status timestamps I receive from people with a recent
+  // Sametime client make no sense.  This patch simply sets the timestamp to 0,
+  // as I have no idea how to interpret these time values.
+
+  // Quick'n ugly hack for recent Sametime clients
+  stat->time = 0;
 }
 
 
@@ -878,24 +889,25 @@ gboolean mwAwareIdBlock_equal(const struct mwAwareIdBlock *a,
 /* 8.4.2.4 Snapshot */
 
 void mwAwareSnapshot_get(struct mwGetBuffer *b, struct mwAwareSnapshot *idb) {
-  guint32 junk;
-  char *empty = NULL;
+  guint32 end_of_block;
 
   g_return_if_fail(b != NULL);
   g_return_if_fail(idb != NULL);
 
-  guint32_get(b, &junk);
+  guint32_get(b, &end_of_block);
   mwAwareIdBlock_get(b, &idb->id);
   mwString_get(b, &idb->group);
   gboolean_get(b, &idb->online);
 
-  g_free(empty);
-
   if(idb->online) {
     mwString_get(b, &idb->alt_id);
     mwUserStatus_get(b, &idb->status);
     mwString_get(b, &idb->name);
   }
+
+  if(b->ptr < b->buf + end_of_block) {
+    mwGetBuffer_advance(b, b->buf + end_of_block - b->ptr);
+  }
 }
 
 
