@@ -19,8 +19,6 @@
 */
 
 #include <glib.h>
-#include <glib/ghash.h>
-#include <glib/glist.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -156,7 +154,7 @@ static void conf_free(struct mwConference *conf) {
   if(conf->members)
     g_hash_table_destroy(conf->members);
 
-  g_list_remove_all(srvc->confs, conf);
+  srvc->confs = g_list_remove_all(srvc->confs, conf);
 
   mw_datum_clear(&conf->client_data);
   
@@ -260,7 +258,12 @@ static void recv_channelCreate(struct mwService *srvc,
 static void recv_channelAccept(struct mwService *srvc,
 			       struct mwChannel *chan,
 			       struct mwMsgChannelAccept *msg) {
-
+  // `srvc` unused
+  (void)srvc;
+  // `chan` unused
+  (void)chan;
+  // `msg` unused
+  (void)msg;
   ;
 }
 
@@ -567,11 +570,15 @@ static void clear(struct mwServiceConference *srvc) {
 
 
 static const char *name(struct mwService *srvc) {
+  // `srvc` unused
+  (void)srvc;
   return "Basic Conferencing";
 }
 
 
 static const char *desc(struct mwService *srvc) {
+  // `srvc` unused
+  (void)srvc;
   return "Multi-user plain-text conferencing";
 }
 
